@@ -32,6 +32,14 @@ class Batch(object):
         self.config = config
         self.h = str(uuid4())
         self.setup_logging()
+
+        # set specific options
+        if self.config.get('opts', False):
+            self.config['reset'] = self.config['opts'].reset
+            print("set config reset to '%s'" % self.config['reset'])
+            self.config['forcedelete'] = self.config['opts'].forcedelete
+            print("set config forcedelete to '%s'" % self.config['forcedelete'])
+
         self.setup_work_dirs()
         self.setup_template_environment()
         self.setup_document_templates()
@@ -40,10 +48,21 @@ class Batch(object):
         self.function_meta = {}
         self.documents = {}
 
-        # set specific options
-        if self.config.get('opts', False):
-            self.config['reset'] = self.config['opts'].reset
-            self.config['forcedelete'] = self.config['opts'].forcedelete
+    def is_opt_reset(self):
+        if self.config.get('reset', False):
+            self.logger.debug("returning bool True from is_opt_reset")
+            return True
+        else:
+            self.logger.debug("returning bool False from is_opt_reset")
+            return False
+
+    def is_opt_forcedelete(self):
+        if self.config.get('forcedelete') in (True, "true", "True"):
+            self.logger.debug("returning bool True from is_opt_forcedelete")
+            return True
+        else:
+            self.logger.debug("returning bool False from is_opt_forcedelete")
+            return False
 
     def setup_logging(self):
         self.logger = logging.getLogger(name="precipy")
@@ -75,6 +94,11 @@ class Batch(object):
         self.output_bucket_name = self.config.get('output_bucket_name', "output")
         self.tempdir = Path(self.config.get('tempdir', tempfile.gettempdir())) / "precipy"
 
+        if self.is_opt_reset():
+            self.logger.debug("resetting - removing old tempdir %s" % self.tempdir)
+            shutil.rmtree(self.tempdir)
+            os.makedirs(self.tempdir)
+
         self.logger.info("tempdir is %s" % self.tempdir)
 
         self.cachePath = self.tempdir / self.cache_bucket_name
@@ -106,7 +130,7 @@ class Batch(object):
         for storage in self.storages:
             storage.init(self)
             storage.connect()
-            if self.config.get('reset'):
+            if self.is_opt_reset():
                 self.logger.debug("resetting cache for %r" % storage)
                 storage.reset_cache()
 
